@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 12436 2020-07-30 08:41:42Z Lavender $
+# $Id: cms_dumpdata.py 12526 2020-09-24 10:42:30Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-07-30 16:41:42 +0800 (Thu, 30 Jul 2020) $
-# $Revision: 12436 $
+# $Author: Casey $
+# $Date: 2020-09-24 18:42:30 +0800 (Thu, 24 Sep 2020) $
+# $Revision: 12526 $
 
 import os
 import sys
@@ -44,48 +44,56 @@ class Command(BaseCommand):
     def add_arguments(self, parser):
         parser.add_argument('path', type=str, help="path")
         parser.add_argument(
-            '-n', '--noAuth', 
+            '-n', '--noAuth',
             action='store_true',
             help="No export auth data.")
-    
+        parser.add_argument(
+            '-pc', '--permissionAndContenttypes',
+            action='store_true',
+            help="Export auth(permission) and contenttypes data.")
+
     def handle(self, *args, **options):
         if DJANGO_VERSION >= 11100:
             app = apps.get_app_config('filer')
             modelList = [apps.get_model('filer', m) for m in app.models]
         else:
-            app = get_app('filer')        
+            app = get_app('filer')
             modelList = get_models(app)
-        
+
         dataStream = StringIO()
-        
+
         def getObjects():
             for model in modelList:
                 model.objects.queryset_class = QuerySet
                 for obj in model.objects.iterator():
                     yield obj
-                    
+
         if DJANGO_VERSION >= 11100:
             serializers.serialize(
-                'json', getObjects(), indent=2, 
-                use_natural_foreign_keys=True, use_natural_primary_keys=True, 
+                'json', getObjects(), indent=2,
+                use_natural_foreign_keys=True, use_natural_primary_keys=True,
                 stream=dataStream)
         else:
             serializers.serialize(
-                'json', getObjects(), indent=2, 
+                'json', getObjects(), indent=2,
                     use_natural_keys=True, stream=dataStream)
-                
+
         filerData = json.loads(dataStream.getvalue())
-        
+
         try:
-        
-            os.system(
-                "%s manage.py dumpdata -e auth.Permission auth > authData.json" %  
-                sys.executable)
+            if not options['permissionAndContenttypes']:
+                os.system(
+                    "%s manage.py dumpdata -e auth.Permission auth > authData.json" %
+                    sys.executable)
+            else:
+                os.system(
+                     "%s manage.py dumpdata auth contenttypes > authData.json" %
+                    sys.executable)
 
             os.system(
-                "%s manage.py dumpdata cms.Treenode > treenodeData.json" %  
+                "%s manage.py dumpdata cms.Treenode > treenodeData.json" %
                 sys.executable)
-                
+
             excludeApps = [
                 'auth',
                 'sites',
@@ -93,16 +101,16 @@ class Command(BaseCommand):
                 'contenttypes',
                 'cms.Treenode',
             ]
-            
+
             if "Zephyrus.statistics" in settings.INSTALLED_APPS:
                 excludeApps.append("statistics")
             if "Iuno.redirect" in settings.INSTALLED_APPS:
                 excludeApps.append("redirect")
-                
+
             excludeStr = "-e %s" % " -e ".join(excludeApps)
-            
+
             os.system("%s manage.py dumpdata %s > otherData.json" % (sys.executable, excludeStr))
-            
+
             with open('authData.json') as f:
                 content = f.read()
                 authData = json.loads(content[content.index('['):])
@@ -119,14 +127,14 @@ class Command(BaseCommand):
                 for ele in authData:
                     data.append(ele)
 
-            
+
             for ele in filerData:
                 data.append(ele)
             for ele in treenodeData:
                 data.append(ele)
             for ele in otherData:
                 data.append(ele)
-            
+
 
             path = os.path.join(options['path'])
 
@@ -138,17 +146,17 @@ class Command(BaseCommand):
                     if os.path.exists(path):
                         os.remove(path)
                     raise
-        
+
         finally:
-        
+
             if os.path.exists('authData.json'):
                 os.remove('authData.json')
-                
+
             if os.path.exists('treenodeData.json'):
                 os.remove('treenodeData.json')
-                
+
             if os.path.exists('otherData.json'):
                 os.remove('otherData.json')
-                
-            
-        
+
+
+
