@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: fix_template.py 11671 2019-08-07 04:50:27Z Lavender $
+# $Id: fix_template.py 12436 2020-07-30 08:41:42Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-08-07 12:50:27 +0800 (Wed, 07 Aug 2019) $
-# $Revision: 11671 $
+# $Date: 2020-07-30 16:41:42 +0800 (Thu, 30 Jul 2020) $
+# $Revision: 12436 $
 
 import os
 import hashlib
@@ -103,15 +103,15 @@ class Command(BaseCommand):
                     text = text.replace(
                         loadTagHash, 
                         ("{% load cms_tags menu_tags sekizai_tags staticfiles %}"
-                         "{% with '' as CMS_STATIC_DIR %}"))
+                         "{% with '' as CMS_STATIC_PREFIX %}{% with '/' as CMS_LINK_PREFIX %}"))
                     text = text.replace(
-                        jsHash, "{% endwith %}{% render_block 'js' %}")
+                        jsHash, "{% endwith %}{% endwith %}{% render_block 'js' %}")
                     text = text.replace(
-                        cssHash, "{% endwith %}{% render_block 'css' %}")
+                        cssHash, "{% endwith %}{% endwith %}{% render_block 'css' %}")
                     text = text.replace(
                         toolbarHash, 
                         ("{% cms_toolbar %}"
-                         "{% with '' as CMS_STATIC_DIR %}"))
+                         "{% with '' as CMS_STATIC_PREFIX %}{% with '/' as CMS_LINK_PREFIX %}"))
                          
                     if six.PY2:
                         with open(fileName, 'wb') as f:
